@@ -179,13 +179,13 @@ def add_quick_search_filter(qs,search_text):
     return qs.filter(quick_search_filter(qs.model,search_text))
     
 def quick_search_filter(model,search_text,prefix=''):
-    #~ logger.info("20120709 add_quick_search_filter(%s,%r)",qs.model,search_text)
+    #~ logger.info("20130425 quick_search_filter(%s,%r)",model,search_text)
     q = models.Q()
     if model.quick_search_fields is not None:
         for fn in model.quick_search_fields:
             kw = {prefix+fn+"__icontains": search_text}
             q = q | models.Q(**kw)
-            #~ logger.info("20120709 %s__icontains=%r",fn,search_text)
+            #~ logger.info("20130425 %s",kw)
     else:
         for field in model._meta.fields:
             if isinstance(field,models.CharField):
@@ -590,47 +590,20 @@ class Table(AbstractTable):
                 #~ for k,v in b.__dict__.items():
                     #~ if isinstance(v,actions.Action):
                         #~ raise Exception("20130121 Must convert %s.%s to get_model_actions()" % (self.model,k))
-            if True:
-                for b in self.model.mro():
-                    for k,v in b.__dict__.items():
-                        
-                        #~ if isinstance(v,actions.ActionRunner):
-                            #~ print "20130326 ActionRunner %s" % v
-                            #~ v = v.bound_action.action
-                        if isinstance(v,actions.Action):
-                            #~ print "20130326 %s.%s = action %s from %s" % (self,k,v,b)
-                            existing_value = self.__dict__.get(k,None)
-                            if existing_value is not None:
-                                if not isinstance(existing_value,actions.Action):
-                                    raise Exception(
-                                        "%s cannot get model action %s because name is already used for %r" %
-                                        self,k,existing_value)
-                                #~ if self.__dict__.has_key(k):
-                                #~ """
-                                #~ Actions defined in 
-                                #~ If a Table has an attribute
-                                #~ When there is an Action called `foo` 
-                                #~ """
-                                #~ logger.debug("Not overriding %s.%s from %s",self,k,b)
-                                #~ pass
-                            else:
-                                #~ 20130121 : removed two following lines 
-                                #~ v = copy.deepcopy(v)
-                                #~ v.name = None
-                                
-                                #~ def meth(action,ar,elem):
-                                #~     return v.run()
-                                #~ v.run = meth
-                                setattr(self,k,v)
+            for b in self.model.mro():
+                for k,v in b.__dict__.items():
+                    if isinstance(v,actions.Action):
+                        #~ print "20130326 %s.%s = action %s from %s" % (self,k,v,b)
+                        existing_value = self.__dict__.get(k,None)
+                        if existing_value is not None:
+                            if not isinstance(existing_value,actions.Action):
+                                raise Exception(
+                                    "%s cannot get model action %s because name is already used for %r" %
+                                    self,k,existing_value)
+                        else:
+                            setattr(self,k,v)
                       
           
-            #~ ma = getattr(self.model,'_lino_model_actions',None)
-            #~ if ma is not None:
-                #~ for k,v in ma.items():
-                    #~ v = copy.deepcopy(v)
-                    #~ v.name = None
-                    #~ setattr(self,k,v)
-                    
                     
               
             for name in ('workflow_state_field','workflow_owner_field'):
