@@ -565,8 +565,9 @@ class TableRequest(ActionRequest):
         if self.master_instance is not None:
             if self.master is not None:
                 bp[constants.URL_PARAM_MASTER_PK] = self.master_instance.pk
-                mt = ContentType.objects.get_for_model(self.master_instance.__class__).pk
-                bp[constants.URL_PARAM_MASTER_TYPE] = mt
+                if ContentType._meta.installed:
+                    mt = ContentType.objects.get_for_model(self.master_instance.__class__).pk
+                    bp[constants.URL_PARAM_MASTER_TYPE] = mt
             else:
                 bp[constants.URL_PARAM_MASTER_PK] = self.master_instance
         return kw
@@ -584,7 +585,7 @@ class TableRequest(ActionRequest):
             kw.update(known_values=self.known_values)
         u = self.get_user()
         if u is not None:
-            kw.update(su=u.username)
+            kw.update(user=u.username)
         #~ return self.__class__.__name__ + '(%s)' % kw
         #~ return self.__class__.__name__ + ' '+str(self.bound_action)+'(%s)' % kw
         return "<%s %s(%s)>" %  (self.__class__.__name__,self.bound_action.full_name(),kw)
@@ -941,12 +942,14 @@ class AbstractTable(actors.Actor):
     #~ @classmethod
     #~ def get_detail(self):
         #~ return None
-        
-    @classmethod
-    def get_row_permission(self,obj,ar,state,ba):
-        if self.get_data_rows:
-            return ba.action.readonly
-        return True
+
+    #~ removed 20130424 because that doesn't work for PendingCourseRequests
+    #~ i.e. both get_data_rows and editable
+    #~ @classmethod
+    #~ def get_row_permission(self,obj,ar,state,ba):
+        #~ if self.get_data_rows:
+            #~ return ba.action.readonly
+        #~ return True
         
         
     @classmethod
@@ -1028,8 +1031,12 @@ class AbstractTable(actors.Actor):
     @classmethod
     def request(self,master_instance=None,**kw):
         kw.update(actor=self)
-        kw.update(master_instance=master_instance)
+        if master_instance is not None:
+            kw.update(master_instance=master_instance)
         ar = TableRequest(**kw)
+        #~ if self.__name__ == 'RetrieveTIGroupsResult':
+            #~ print 20130425, __file__, ar
+        
         #~ if self.__name__ == 'PrintExpensesByBudget':
             #~ assert ar.master_instance is not None
             #~ print '20130327 tables.py', self, ar.master_instance
@@ -1069,6 +1076,10 @@ class AbstractTable(actors.Actor):
     @classmethod
     def to_rst(cls,ar,column_names=None,**kwargs):
         fields, headers, widths = ar.get_field_info(column_names)
+        #~ # in case column_names contains remote fields
+        #~ settings.SITE.startup() 
+        #~ settings.SITE.resolve_virtual_fields()
+
         
         grid = ar.ah.list_layout.main
                     
