@@ -783,8 +783,7 @@ class ContactRelated(dd.Model):
       
     @classmethod
     def contact_person_choices_queryset(cls,company):
-    #~ def contact_choices_queryset(cls,company):
-        return Person.objects.filter(rolesbyperson__company=company).distinct()
+        return settings.SITE.modules.contacts.Person.objects.filter(rolesbyperson__company=company).distinct()
 
     def full_clean(self,*args,**kw):
         if not settings.SITE.loading_from_dump:
@@ -917,4 +916,4 @@ def setup_explorer_menu(site,ui,profile,m):
 #~ def setup_quicklinks(site,ui,user,m):
     #~ m.add_action(Person.detail_action)
         
-  
\ No newline at end of file
+  
