@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2011-2012 Luc Saffre
+## Copyright 2011-2013 Luc Saffre
 ## This file is part of the Lino project.
 ## Lino is free software; you can redistribute it and/or modify 
 ## it under the terms of the GNU General Public License as published by
@@ -19,18 +19,23 @@ from lino.modlib.vocbook.fr import French, Autre, Nom, NomPropre, Adjectif, Nume
 from lino.modlib.vocbook.et import Estonian
 from lino.modlib.vocbook.base import Book, FR, M, F, ET, PRON, GEON, GEOM, GEOF
 
-if len(sys.argv) != 3:
-    raise Exception("""
-Usage : %(cmd)s rst OUTPUT_ROOT_DIR
-    %(cmd)s odt OUTPUT_FILE
-""" % dict(cmd=sys.argv[0]))
-output_format = sys.argv[1]
+if __name__ == '__main__':
+    if len(sys.argv) != 3:
+        raise Exception("""
+    Usage : %(cmd)s rst OUTPUT_ROOT_DIR
+        %(cmd)s odt OUTPUT_FILE
+    """ % dict(cmd=sys.argv[0]))
+    output_format = sys.argv[1]
+else:
+    output_format = 'rst' # 
+    
 if output_format == "rst":
     FULL_CONTENT = False
 else:
     FULL_CONTENT = False
 
 HAS_FUN = True
+HAS_EXERCICES = True
 
 book = Book(French,Estonian,
     title=u"Kutsealane prantsuse keel kokadele",
@@ -121,6 +126,8 @@ Kokadele = Vocabulary.add_section(u"Kulinaaria")
 if HAS_FUN:
     Fun = Vocabulary.add_section(u"Laulud")
 
+if HAS_EXERCICES:
+    Exercices = Vocabulary.add_section(u"Harjutused")
 
 
 
@@ -270,6 +277,99 @@ le paradis [para'di] : paradiis
 """)
 
 
+Intro.add_lesson(u"O on kinnine või avatud", u"""
+Helid **[o]** ja **[ö]** on eesti keeles alati *kinnised*.
+Prantsuse keeles on lisaks ka *avatud* vormid.
+Hääldamiskirjelduses on kinnine vorm **väikese** tähega ja
+avatud vorm **suure** tähega.
+""")
+Intro.parse_words(Autre,u"""
+je donne [dOn] : ma annan
+je dors [dOOr] : ma magan
+""")
+Intro.parse_words(Nom,u"""
+le dos [do] : selg
+le mot [mo] : sõna
+le tome [toom] : köide
+""")
+
+if FULL_CONTENT:
+  Intro.parse_words(Nom,u"""
+  la mort [mOOr] : surm
+  le or [OOr] : kuld
+  le boulot [bu'lo] : töö (kõnekeel)
+  le bouleau [bu'loo] : kask
+  le bureau [bü'roo] : büroo
+  """)
+  
+if not FULL_CONTENT:
+  
+    Intro.add_lesson(u"Cold gold, big pigs and downtowns", u"""
+    Erinevus tugeva ja nõrda K, P või T vahel on prantsuse keeles sama 
+    oluline nagu inglise ja saksa keeles.
+    """)
+    Intro.parse_words(Autre,u"""
+    la gare [gaar] : raudteejaam
+    le car [kaar] : reisibuss
+    la bière [bjäär] : õlu
+    la pierre [pjäär] : kivi
+    le doigt [dwa] : sõrm
+    le toit [twa] : katus
+    """)
+
+
+else:  
+
+    Eesti.add_lesson(u"b ja p", u"""
+    b ja p on prantsuse keeles selgelt erinevad.
+    """)
+    Eesti.parse_words(None,u"""
+    la bière [bjäär] : õlu
+    la pierre [pjäär] : kivi
+    le bon [bO~] : tšekk | talong
+    le pont [pO~] : sild
+    le bon ton [bO~'tO~] : viisakus
+    le ponton [pO~'tO~] : pontoon (nt. pontoonsild)
+    la peau [poo] : nahk
+    beau (m.) : ilus
+    le bois [bwa] : puu (materjal) | mets
+    le poids [pwa] : kaal
+    """)
+
+
+
+    Eesti.add_lesson(u"d ja t", u"""
+    d ja t on prantsuse keeles selgelt erinevad.
+    """)
+    Eesti.parse_words(None,u"""
+    le don [dO~] : annetus
+    le ton [tO~] : toon
+    le centre ['sA~trə] : keskus
+    la cendre ['sA~drə] : tuhk
+    je donne [dOn] : ma annan
+    la tonne [tOn] : tonn
+    le toit [twa] : katus
+    le doigt [dwa] : sõrm
+    """)
+
+    Eesti.add_lesson(u"g ja k", u"""
+    g ja k on prantsuse keeles selgelt erinevad.
+    """)
+    Eesti.parse_words(None,u"""
+    le gond [gO~] : uksehing
+    le con [kO~] : loll
+    la gare [gaar] : raudteejaam
+    le car [kaar] : reisibuss
+    car [kaar] : sest
+    le garçon [gar'sO~] : poiss
+    Qui est Guy? [ki ä gi] : Kes on Guy?
+    """)
+
+  
+
+
+
+
 Reeglid.add_lesson(u"u", intro=u"""
 **u** (siis kui see pole teise täishäälikuga koos)
 hääldatakse **[ü]** või **[üü]**.
@@ -452,36 +552,6 @@ le *hors d'œuvre [hOOr 'dÖÖvrə] : eelroog
 
 
 
-
-
-
-
-
-Intro.add_lesson(u"O on kinnine või avatud", u"""
-Helid **[o]** ja **[ö]** on eesti keeles alati *kinnised*.
-Prantsuse keeles on lisaks ka *avatud* vormid.
-Hääldamiskirjelduses on kinnine vorm **väikese** tähega ja
-avatud vorm **suure** tähega.
-""")
-Intro.parse_words(Autre,u"""
-je donne [dOn] : ma annan
-je dors [dOOr] : ma magan
-""")
-Intro.parse_words(Nom,u"""
-le dos [do] : selg
-le mot [mo] : sõna
-le tome [toom] : köide
-""")
-
-if FULL_CONTENT:
-  Intro.parse_words(Nom,u"""
-  la mort [mOOr] : surm
-  le or [OOr] : kuld
-  le boulot [bu'lo] : töö (kõnekeel)
-  le bouleau [bu'loo] : kask
-  le bureau [bü'roo] : büroo
-  """)
-
 if HAS_FUN:
 
     Fun.add_lesson(u"Frère Jacques", u"""
@@ -1093,53 +1163,6 @@ le écureuil [ekü'rÖj] : orav
 
 
 
-if FULL_CONTENT:
-
-    Eesti.add_lesson(u"b ja p", u"""
-    b ja p on prantsuse keeles selgelt erinevad.
-    """)
-    Eesti.parse_words(None,u"""
-    la bière [bjäär] : õlu
-    la pierre [pjäär] : kivi
-    le bon [bO~] : tšekk | talong
-    le pont [pO~] : sild
-    le bon ton [bO~'tO~] : viisakus
-    le ponton [pO~'tO~] : pontoon (nt. pontoonsild)
-    la peau [poo] : nahk
-    beau (m.) : ilus
-    le bois [bwa] : puu (materjal) | mets
-    le poids [pwa] : kaal
-    """)
-
-
-
-    Eesti.add_lesson(u"d ja t", u"""
-    d ja t on prantsuse keeles selgelt erinevad.
-    """)
-    Eesti.parse_words(None,u"""
-    le don [dO~] : annetus
-    le ton [tO~] : toon
-    le centre ['sA~trə] : keskus
-    la cendre ['sA~drə] : tuhk
-    je donne [dOn] : ma annan
-    la tonne [tOn] : tonn
-    le toit [twa] : katus
-    le doigt [dwa] : sõrm
-    """)
-
-    Eesti.add_lesson(u"g ja k", u"""
-    g ja k on prantsuse keeles selgelt erinevad.
-    """)
-    Eesti.parse_words(None,u"""
-    le gond [gO~] : uksehing
-    le con [kO~] : loll
-    la gare [gaar] : raudteejaam
-    le car [kaar] : reisibuss
-    car [kaar] : sest
-    le garçon [gar'sO~] : poiss
-    Qui est Guy? [ki ä gi] : Kes on Guy?
-    """)
-
 
 
 if False:
@@ -2205,6 +2228,38 @@ if FULL_CONTENT:
     le dauphinois [dofinw'a] : lõunaprantsuse dialekt
     """
 
+if HAS_EXERCICES:
+    Exercices.add_lesson(u"Lugeda oskad?", u"""
+Õpetaja kirjutab tahvlile sari hääldamiskirjeldusi.
+Õpilased loevad ette.
+Ainult lugeda, mitte tõlkida.
+""")
+    Exercices.parse_words(None,u"""
+    au clair de lune [okläärdə'lün] : kuuvalguses
+    le cœur de filet [kÖÖr də fi'lä] : veise sisefilee
+    le dessert [des'säär] : magustoit
+    la mousse au chocolat [musošoko'la] : šokoladivaht
+    le pot-au-feu [poto'föö] : ühepajatoit
+    le petit-beurre [pəti'bÖÖr]: (kuiv küpsis)
+    la sauce chasseur [soos ša'sÖÖr] : jahimehe kaste
+    Poitou [pwa'tu] : -
+    la sauce italienne [soosital'jän] : itaalia kaste
+    le gratin dauphinois [gra'tÄ~ dofinw'a] : (tuntud retsept)
+    """)
+    
+    Exercices.add_lesson(u"Kirjutada oskad?", u"""
+Õpetaja loeb ette sari sõnu.
+Õpilased kirjutavad paberile, kasutades hääldamiskirjelduse tähestik.
+""")
+    Exercices.parse_words(None,u"""
+le chevreuil [šəv'rÖj] : metskits
+le soleil [so'leij] : päike
+la boisson [bwa'sO~] : jook
+le poisson [pwa'sO~] : kala
+le requin [rə'kÄ~] : haikala
+la cuillère [kwi'jäär] : lusikas
+""")
+
 
 if __name__ == '__main__':
     if output_format == "rst":
