@@ -58,7 +58,6 @@ class Site(Site,ledger.SiteMixin):
         #~ return _("a Lino application to make Belgian accounting simple.")
     #~ description = property(get_description)
         
-    #~ def get_app_source_file(self): return __file__
       
     #~ def get_application_info(self):
         #~ return (__name__,__version__,__url__)
@@ -83,6 +82,8 @@ class Site(Site,ledger.SiteMixin):
         add('900', _("Administrator"),   'A A A', 'admin')
         
             
+    partners_app_label = 'partners'
+    
     def get_installed_apps(self):
         for a in super(Site,self).get_installed_apps():
             yield a
@@ -91,8 +92,8 @@ class Site(Site,ledger.SiteMixin):
         #~ yield 'django.contrib.auth'
         yield 'lino.modlib.countries'
         #~ yield 'lino.modlib.properties'
-        #~ yield 'lino.modlib.partners'
-        yield 'lino.modlib.contacts'
+        yield 'lino.modlib.partners'
+        #~ yield 'lino.modlib.contacts'
         #~ yield 'lino.modlib.households'
         yield 'lino.modlib.products'
         yield 'lino.modlib.accounts'
@@ -115,5 +116,5 @@ class Site(Site,ledger.SiteMixin):
         yield 'lino.projects.cosi'
 
 
-SITE = Site(__file__,globals())
+SITE = Site(globals())
 
