@@ -869,7 +869,8 @@ class Site(lino.Site):
                 #~ raise Exception("""\
     #~ `user_model` is not None, but no `remote_user_header` in your settings.SITE.""")
         #~ yield 'lino.utils.editing.EditingMiddleware'
-        yield 'lino.utils.ajax.AjaxExceptionResponse'
+        if True:
+            yield 'lino.utils.ajax.AjaxExceptionResponse'
 
         if False: # not BYPASS_PERMS:
             yield 'django.contrib.auth.middleware.RemoteUserMiddleware'
@@ -991,17 +992,48 @@ class Site(lino.Site):
                 yield ("Extensible",version ,"http://ext.ensible.com/products/calendar/")
             yield ("Silk Icons",'1.3',"http://www.famfamfam.com/lab/icons/silk/")
 
-            
-          
 
     def welcome_html(self,ui=None):
         """
-        Text to display in the "about" dialog of a GUI application.
+        Return a HTML version of the "This is APPLICATION 
+        version VERSION using ..." text. to be displayed in the 
+        About dialog, in the plain html footer, and maybe at other 
+        places.
         """
-        sep = '<br/>'
-        #~ sep = ', '
-        return sep.join(['<a href="%s" target="_blank">%s</a>&nbsp;%s' 
-            % (u,n,v) for n,v,u in self.using(ui)])
+        from lino.utils.xmlgen.html import E
+        from django.utils.translation import ugettext as _
+        
+        p = []
+        sep = ''
+        if self.verbose_name:
+            p.append(_("This is "))
+            if self.url:
+                p.append(E.a(self.verbose_name,href=self.url,target='_blank'))
+            else:
+                p.append(E.b(self.verbose_name))
+            if self.version:
+                p.append(' ')
+                p.append(self.version)
+            sep = _(' using ')
+        
+        for name,version,url in self.using():
+            p.append(sep)
+            p.append(E.a(name,href=url,target='_blank'))
+            p.append(' ')
+            p.append(version)
+            sep = ', '
+        return E.span(*p)
+        
+    #~ def welcome_html(self,ui=None):
+        #~ """
+        #~ Text to display in the "about" dialog of a GUI application.
+        #~ """
+        #~ sep = '<br/>'
+        #~ kw = dict(me=self.site_version(),
+          #~ using = sep.join(['<a href="%s" target="_blank">%s</a>&nbsp;%s' 
+            #~ % (u,n,v) for n,v,u in self.using(ui)]))
+        #~ return  "This is %(me)s using %(using)s." % kw
+            
               
     def login(self,username):
         """
