@@ -687,7 +687,12 @@ class FieldElement(LayoutElement):
             kw.update(sortable=False)
         w = self.width or self.preferred_width
         #~ kw.update(width=w*EXT_CHAR_WIDTH)
-        kw.update(width=js_code("Lino.chars2width(%d)" % w))
+        kw.update(width=js_code("Lino.chars2width(%d)" % (w+1)))
+        """
+        We add 1 character (9 pixels) to the theoretic width.
+        e.g. the columns "16-24" etc in `courses.PendingCourseRequests`
+        has w=5 and should be rendered so that the header is visible.
+        """
         return kw    
         
         
@@ -1273,8 +1278,8 @@ class DisplayElement(FieldElement):
     """
     ExtJS element to be used for :class:`DisplayFields <lino.core.fields.DisplayField>`.
     """
-    preferred_width = 30
-    preferred_height = 3
+    #~ preferred_width = 30
+    #~ preferred_height = 3
     ext_suffix = "_disp"
     #~ declare_type = jsgen.DECLARE_THIS
     declare_type = jsgen.DECLARE_VAR
@@ -1284,6 +1289,8 @@ class DisplayElement(FieldElement):
         kw.setdefault('value','<br/>') # see blog/2012/0527
         kw.update(always_enabled=True)
         FieldElement.__init__(self,*args,**kw)
+        self.preferred_height = self.field.preferred_height
+        self.preferred_width = self.field.preferred_width
         if self.field.max_length:
             self.preferred_width = self.field.max_length
             
@@ -2011,22 +2018,13 @@ class GridElement(Container):
         #~ kw.update(boxMinWidth=500)
         self.columns = columns
         
-        vc = dict(emptyText=_("No data to display."))
-        if rpt.editable:
-            vc.update(getRowClass=js_code('Lino.getRowClass'))
+        #~ vc = dict(emptyText=_("No data to display."))
+        #~ if rpt.editable:
+            #~ vc.update(getRowClass=js_code('Lino.getRowClass'))
+        #~ if rpt.auto_fit_column_widths:
+            #~ vc.update(forceFit=True)
+        #~ kw.update(viewConfig=vc)
         
-        #~ //autoScroll:true,
-        #~ //autoFill:true,
-        #~ //forceFit=True,
-        #~ //enableRowBody=True,
-        #~ //~ showPreview:true,
-        #~ //~ scrollOffset:200,
-        #~ //~ enableRowBody: true,
-        
-        if rpt.auto_fit_column_widths:
-            vc.update(forceFit=True)
-            
-        kw.update(viewConfig=vc)
         kw.setdefault('label',rpt.label)
         
         add_help_text(kw,rpt.help_text,rpt.title or rpt.label,rpt.app_label,rpt.actor_id)
@@ -2096,7 +2094,10 @@ class GridElement(Container):
     def row2text(self,ar,fields,row,sums):
         for i,fld in enumerate(fields):
             if fld.field is not None:
-                v = fld.field._lino_atomizer.full_value_from_object(row,ar)
+                try: # was used to find bug 20130422
+                    v = fld.field._lino_atomizer.full_value_from_object(row,ar)
+                except Exception as e:
+                    v = "%s:\n%s" % (fld.field,e)
                 if v is None:
                     yield ''
                 else:
@@ -2276,10 +2277,11 @@ def field2elem(layout_handle,field,**kw):
         return RequestFieldElement(layout_handle,field,**kw)
         
     selector_field = field
-    if isinstance(field,dd.VirtualField):
-        selector_field = field.return_type
-    elif isinstance(field,fields.RemoteField):
+    if isinstance(field,fields.RemoteField):
         selector_field = field.field
+    if isinstance(selector_field,dd.VirtualField):
+        selector_field = selector_field.return_type
+    # remeber the case of RemoteField to VirtualField
     
     #~ if str(layout_handle.layout._datasource) == 'pcsw.UsersWithClients':
         #~ if field is not selector_field:
@@ -2295,7 +2297,7 @@ def field2elem(layout_handle,field,**kw):
         raise NotImplementedError("No LayoutElement for VirtualField %s on %s in %s" % (
           field.name,field.return_type.__class__,layout_handle.layout))
     if isinstance(field,fields.RemoteField):
-        raise NotImplementedError("No LayoutElement for RemoteField %s on %s" % (
+        raise NotImplementedError("No LayoutElement for RemoteField %s to %s" % (
           field.name,field.field.__class__))
     raise NotImplementedError("No LayoutElement for %s (%s) in %s" 
         % (field.name,field.__class__,layout_handle.layout))
