@@ -394,11 +394,14 @@ def make_view_permission_handler_(
             return True
     
     if debug_permissions: # False:
+        #~ logger.info("20130424 install debug_permissions for %s",
+            #~ [actor,readonly,debug_permissions,
+            #~ user_level,user_groups,allow,auth,owner,states])
         allow4 = allow
         def allow(action,profile):
             v = allow4(action,profile)
             if True: # not v:
-                logger.info(u"debug_permissions %r required(%s,%s), allow(%s)--> %s",
+                logger.info(u"debug_permissions (view) %r required(%s,%s), allow(%s)--> %s",
                   action,user_level,user_groups,profile,v)
             return v
     return allow
@@ -407,6 +410,14 @@ def make_view_permission_handler_(
 def make_permission_handler_(
     elem,actor,readonly,debug_permissions,
     user_level=None,user_groups=None,states=None,allow=None,owner=None,auth=False):
+        
+    #~ if str(actor) == 'courses.PendingCourseRequests':
+        #~ if allow is None: raise Exception("20130424")
+    
+    #~ if debug_permissions: # False:
+        #~ logger.info("20130424 install debug_permissions for %s",
+            #~ [elem,actor,readonly,debug_permissions,
+            #~ user_level,user_groups,states,allow,owner,auth])
     
     if allow is None:
         def allow(action,user,obj,state):
@@ -417,6 +428,8 @@ def make_permission_handler_(
             allow_before_auth = allow
             def allow(action,user,obj,state):
                 if not user.profile.authenticated:
+                    #~ if action.action_name == 'wf7':
+                        #~ logger.info("20130424 allow_before_auth returned False")
                     return False
                 return allow_before_auth(action,user,obj,state)
             
@@ -427,6 +440,8 @@ def make_permission_handler_(
                 #~ if user.profile.level is None or user.profile.level < user_level:
                 if user.profile.level < user_level:
                     #~ print 20120715, user.profile.level
+                    #~ if action.action_name == 'wf7':
+                        #~ logger.info("20130424 allow_user_level returned False")
                     return False
                 return allow_user_level(action,user,obj,state)
                 
@@ -434,6 +449,8 @@ def make_permission_handler_(
             allow_owner = allow
             def allow(action,user,obj,state):
                 if obj is not None and (user == obj.user) != owner:
+                    #~ if action.action_name == 'wf7':
+                        #~ logger.info("20130424 allow_owner returned False")
                     return False
                 return allow_owner(action,user,obj,state)
                 
@@ -449,7 +466,10 @@ def make_permission_handler_(
                     #~ raise Exception("Invalid UserGroup %r" % g)
             allow1 = allow
             def allow(action,user,obj,state):
-                if not allow1(action,user,obj,state): return False
+                if not allow1(action,user,obj,state): 
+                    #~ if action.action_name == 'wf7':
+                        #~ logger.info("20130424 allow1 returned False")
+                    return False
                 for g in user_groups:
                     level = getattr(user.profile,g+'_level')
                     if level >= user_level:
@@ -506,11 +526,8 @@ def make_permission_handler_(
         allow4 = allow
         def allow(action,user,obj,state):
             v = allow4(action,user,obj,state)
-            if True: # not v:
-                #~ logger.info(u"debug_permissions %s %s.required(%s,%s,%s), allow(%s,%s,%s)--> %s",
-                  #~ actor,action.action_name,user_level,user_groups,states,user.username,obj2str(obj),state,v)
-                logger.info(u"debug_permissions %r required(%s,%s,%s), allow(%s,%s,%s)--> %s",
-                  action,user_level,user_groups,states,user.username,obj2str(obj),state,v)
+            logger.info(u"debug_permissions %r required(%s,%s,%s), allow(%s,%s,%s)--> %s",
+              action,user_level,user_groups,states,user.username,obj2str(obj),state,v)
             return v
     return allow
         
@@ -555,6 +572,7 @@ class AnonymousUser(object):
 class NOT_NEEDED:
     pass
     
+    
 def authenticate(username,password=NOT_NEEDED):
 
     if not username:
@@ -581,75 +599,108 @@ def authenticate(username,password=NOT_NEEDED):
     except settings.SITE.user_model.DoesNotExist,e:
         #~ logger.info("20121104 no username %r",username)
         return None  
-        
-        
-def on_login(request,user):
-    """
-    on multilingual sites, 
-    if URL_PARAM_USER_LANGUAGE is present it overrides user.language.
-    """
-    #~ logger.info("20130313 on_login(%s)" % user)
-    request.user = user
     
-    if len(settings.SITE.languages) > 1:
-    #~ if settings.SITE.languages != None and len(settings.SITE.languages) > 1:
+    
+class AuthMiddleWareBase(object):
+    """
+    Common base class for 
+    :class:`RemoteUserMiddleware`,
+    :class:`SessionsUserMiddleware`
+    and
+    :class:`NoUserMiddleware`.
+    """
+    def get_user_from_request(self, request):
+        raise NotImplementedError
+        
+    def process_request(self, request):
+      
+        #~ print 20130313, request.session.get('username')
+        
+        settings.SITE.startup() 
+        """
+        first request will trigger site startup to load UserProfiles
+        """
+        
+        user = self.get_user_from_request(request)
+        
+        self.on_login(request,user)
+        
         
-        #~ lang = settings.SITE.override_user_language() or request.user.language
-        lang = user.language
-        if lang:
-            translation.activate(lang)
-            request.LANGUAGE_CODE = translation.get_language()
-            #~ logger.info("20121205 on_login %r",lang)
             
-        #~ logger.info("20121205 on_login %r",translation.get_language())
+            
+    def on_login(self,request,user):
+        """
+        The method which is applied when the user has been determined.
+        On multilingual sites, 
+        if URL_PARAM_USER_LANGUAGE is present it overrides user.language.
+        """
+        #~ logger.info("20130313 on_login(%s)" % user)
+        request.user = user
         
+        if len(settings.SITE.languages) > 1:
+        #~ if settings.SITE.languages != None and len(settings.SITE.languages) > 1:
+            
+            #~ lang = settings.SITE.override_user_language() or request.user.language
+            lang = user.language
+            if lang:
+                translation.activate(lang)
+                request.LANGUAGE_CODE = translation.get_language()
+                #~ logger.info("20121205 on_login %r",lang)
+                
+            #~ logger.info("20121205 on_login %r",translation.get_language())
+            
+              
+        if request.method == 'GET':
+            rqdata = request.GET
+        elif request.method in ('PUT','DELETE'):
+            rqdata = http.QueryDict(request.body) # raw_post_data before Django 1.4
+        elif request.method == 'POST':
+            rqdata = request.POST
+        else: 
+            # e.g. OPTIONS, HEAD
+            request.requesting_panel = None
+            request.subst_user = None
+            return
+        #~ else: # DELETE
+            #~ request.subst_user = None
+            #~ request.requesting_panel = None
+            #~ return
+            
+        if len(settings.SITE.languages) > 1:
+        #~ if settings.SITE.languages != None and len(settings.SITE.languages) > 1:
           
-    if request.method == 'GET':
-        rqdata = request.GET
-    elif request.method in ('PUT','DELETE'):
-        rqdata = http.QueryDict(request.body) # raw_post_data before Django 1.4
-    elif request.method == 'POST':
-        rqdata = request.POST
-    else: 
-        #~ raise Exception("Unknown HTTP method '%s'" % request.method)
-        # e.g. OPTIONS
-        return
-    #~ else: # DELETE
-        #~ request.subst_user = None
-        #~ request.requesting_panel = None
-        #~ return
+            ul = rqdata.get(constants.URL_PARAM_USER_LANGUAGE,None)
+            if ul:
+                translation.activate(ul)
+                request.LANGUAGE_CODE = translation.get_language()
+          
+        su = rqdata.get(constants.URL_PARAM_SUBST_USER,None)
+        if su is not None:
+            if su:
+                try:
+                    su = settings.SITE.user_model.objects.get(id=int(su))
+                    #~ logger.info("20120714 su is %s",su.username)
+                except settings.SITE.user_model.DoesNotExist, e:
+                    su = None
+            else:
+                su = None # e.g. when it was an empty string "su="
+        request.subst_user = su
+        request.requesting_panel = rqdata.get(constants.URL_PARAM_REQUESTING_PANEL,None)
+        #~ logger.info("20121228 subst_user is %r",request.subst_user)
+        #~ if request.subst_user is not None and not isinstance(request.subst_user,settings.SITE.user_model):
+            #~ raise Exception("20121228")
+        
         
-    if len(settings.SITE.languages) > 1:
-    #~ if settings.SITE.languages != None and len(settings.SITE.languages) > 1:
-      
-        ul = rqdata.get(constants.URL_PARAM_USER_LANGUAGE,None)
-        if ul:
-            translation.activate(ul)
-            request.LANGUAGE_CODE = translation.get_language()
-      
-    su = rqdata.get(constants.URL_PARAM_SUBST_USER,None)
-    if su is not None:
-        if su:
-            try:
-                su = settings.SITE.user_model.objects.get(id=int(su))
-                #~ logger.info("20120714 su is %s",su.username)
-            except settings.SITE.user_model.DoesNotExist, e:
-                su = None
-        else:
-            su = None # e.g. when it was an empty string "su="
-    request.subst_user = su
-    request.requesting_panel = rqdata.get(constants.URL_PARAM_REQUESTING_PANEL,None)
-    #~ logger.info("20121228 subst_user is %r",request.subst_user)
-    #~ if request.subst_user is not None and not isinstance(request.subst_user,settings.SITE.user_model):
-        #~ raise Exception("20121228")
-    
-    
             
             
 
             
-class RemoteUserMiddleware(object):
+class RemoteUserMiddleware(AuthMiddleWareBase):
     """
+    Middleware which Lino automatically uses when bith
+    :attr:`remote_user_header <lino.Site.remote_user_header>` 
+    and :attr:`user_model <lino.Site.user_model>` are not empty.
+    
     This does the same as
     `django.contrib.auth.middleware.RemoteUserMiddleware`, 
     but in a simplified manner and without using Sessions.
@@ -662,10 +713,7 @@ class RemoteUserMiddleware(object):
     
     """
     
-    def process_request(self, request):
-      
-        settings.SITE.startup() # trigger site startup to load UserProfiles
-        
+    def get_user_from_request(self, request):
         username = request.META.get(
             settings.SITE.remote_user_header,settings.SITE.default_user)
             
@@ -683,17 +731,18 @@ class RemoteUserMiddleware(object):
             logger.info("Unknown or inactive username %r.",username)
             raise exceptions.PermissionDenied()
               
-        on_login(request,user)
+        return user
     
 
-class SessionUserMiddleware(object):
+class SessionUserMiddleware(AuthMiddleWareBase):
+    """
+    Middleware which Lino automatically uses when 
+    :attr:`remote_user_header <lino.Site.remote_user_header>` is None
+    and :attr:`user_model <lino.Site.user_model>` not.
+    """
 
-    def process_request(self, request):
+    def get_user_from_request(self, request):
       
-        #~ print 20130313, request.session.get('username')
-        
-        settings.SITE.startup() # trigger site startup to load UserProfiles
-        
         user = authenticate(request.session.get('username'),
             request.session.get('password'))
         
@@ -701,17 +750,17 @@ class SessionUserMiddleware(object):
             logger.debug("Login failed from session %s", request.session)
             user = AnonymousUser.instance()
         
-        on_login(request,user)
+        return user
         
         
-class NoUserMiddleware(object):
-  
-    def process_request(self, request):
-      
-        settings.SITE.startup() # trigger site startup to load UserProfiles
+class NoUserMiddleware(AuthMiddleWareBase):
+    """
+    Middleware which Lino automatically uses when 
+    :attr:`lino.Site.user_model` is None.
+    """
+    def get_user_from_request(self, request):
+        
+        return AnonymousUser.instance()
         
-        user = AnonymousUser.instance()
-        
-        on_login(request,user)
         
         
